@@ -42,13 +42,15 @@ QWidget *FilterActionSetTransport::createParamWidget(QWidget *parent) const
     transportCombobox->setObjectName(QStringLiteral("transportcombobox"));
     setParamWidgetValue(transportCombobox);
 
-    connect(transportCombobox, static_cast<void (MailTransport::TransportComboBox::*)(int)>(&MailTransport::TransportComboBox::currentIndexChanged), this, &FilterActionSetTransport::filterActionModified);
+    connect(transportCombobox, static_cast<void (MailTransport::TransportComboBox::*)(int)>(&MailTransport::TransportComboBox::currentIndexChanged), this,
+            &FilterActionSetTransport::filterActionModified);
 
     return transportCombobox;
 }
 
 FilterActionSetTransport::FilterActionSetTransport(QObject *parent)
-    : FilterAction(QStringLiteral("set transport"), i18n("Set Transport To"), parent), mParameter(-1)
+    : FilterAction(QStringLiteral("set transport"), i18n("Set Transport To"), parent)
+    , mParameter(-1)
 {
 }
 
@@ -99,7 +101,7 @@ SearchRule::RequiredPart FilterActionSetTransport::requiredPart() const
 
 void FilterActionSetTransport::applyParamWidgetValue(QWidget *paramWidget)
 {
-    const MailTransport::TransportComboBox *comboBox = dynamic_cast<MailTransport::TransportComboBox *>(paramWidget);
+    const MailTransport::TransportComboBox *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
     Q_ASSERT(comboBox);
 
     mParameter = comboBox->currentTransportId();
@@ -108,7 +110,7 @@ void FilterActionSetTransport::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionSetTransport::clearParamWidget(QWidget *paramWidget) const
 {
-    MailTransport::TransportComboBox *comboBox = dynamic_cast<MailTransport::TransportComboBox *>(paramWidget);
+    MailTransport::TransportComboBox *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIndex(0);
@@ -116,7 +118,7 @@ void FilterActionSetTransport::clearParamWidget(QWidget *paramWidget) const
 
 void FilterActionSetTransport::setParamWidgetValue(QWidget *paramWidget) const
 {
-    MailTransport::TransportComboBox *comboBox = dynamic_cast<MailTransport::TransportComboBox *>(paramWidget);
+    MailTransport::TransportComboBox *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentTransport(mParameter);
@@ -124,7 +126,7 @@ void FilterActionSetTransport::setParamWidgetValue(QWidget *paramWidget) const
 
 bool FilterActionSetTransport::isEmpty() const
 {
-    return (mParameter == -1);
+    return mParameter == -1;
 }
 
 void FilterActionSetTransport::argsFromString(const QString &argsStr)
@@ -155,4 +157,3 @@ QString FilterActionSetTransport::informationAboutNotValidAction() const
 {
     return i18n("Mail transport not defined.");
 }
-
